@@ -11,10 +11,10 @@ rules were obtained for Curtis using the "decision tree approach", in which
 some existent data was given to a decision tree classifier, and it categorized
 the data into branches of rules and decisions.
 """
-__version__ = '0.1.3'
+__version__ = '0.2.0'
 
 try:
-    from .fact import CurtisFact
+    from .facts import CurtisFacts
     from .engine import CurtisEngine
     from .exceptions import exceptions
     from .utils import utils
